@@ -146,7 +146,7 @@ class MarkClient:
         Post request to the MARk server
         '''
         parameters["id"] = self.client_id
-        response = requests.post(self.server_url, data=json.dumps(parameters), proxies=self.proxy)
+        response = requests.post(self.server_url, data=json.dumps(parameters), proxies=self.proxy, timeout=5)
         if self.verbose:
             print("-- Status of the "+parameters["method"]+" request:")
             print(f"-- {response.json()}")
